@@ -1,4 +1,4 @@
-//$Id: button.cc,v 1.31 2002/01/28 18:21:58 cactus Exp $ -*- c++ -*-
+//$Id: button.cc,v 1.32 2002/03/15 17:47:08 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -27,7 +27,7 @@ using namespace Guikachu::GUI::FormEditor;
 Button::Button (Resources::Form   *owner,
 		const std::string &id):
     Widget (owner, id),
-    Resizeable (changed),
+    ResizeableWidget (changed),
     AutoWidth (changed),
     AutoHeight (changed),
     Textual (changed, id),
