@@ -1,4 +1,4 @@
-//$Id: canvasitem.h,v 1.15 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
+//$Id: canvasitem.h,v 1.17 2002/01/29 22:55:05 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -56,11 +56,6 @@ namespace Guikachu
 		    double delta_remainder_x, delta_remainder_y;
 		} drag_context;
 		
-	    protected:
-		Gnome::CanvasGroup *parent_group;
-		Gnome::CanvasGroup *item;
-		virtual void set_canvas_item (Gnome::CanvasGroup *item);
-		
 	    protected:
 		CanvasItem (FormElement        *form_element,
 			    Gnome::CanvasGroup *parent_group);
@@ -68,17 +63,40 @@ namespace Guikachu
 	    public:
 		virtual ~CanvasItem ();
 
+	    protected:
+		Gnome::CanvasGroup *parent_group;
+		Gnome::CanvasGroup *item_group;
+		Gnome::CanvasGroup *draw_group;
+		Gnome::CanvasGroup *overlay_group;
+		Gnome::CanvasGroup *item;
+		
+		void set_canvas_item (Gnome::CanvasGroup *item);
+		SigC::Signal0<void> canvas_item_changed;
+
+	    public:
 		virtual void update () = 0;
-		virtual void move (int dx, int dy);
-		    
+		
 		SigC::Signal0<void> clicked;
 		SigC::Signal0<void> released;
 
+		// Position and drag & drop
+		virtual void move (int dx, int dy);
+
 		SigC::Signal0<void>           drag_begin;
 		SigC::Signal2<void, int, int> drag_motion; // arguments are dx and dy
 		SigC::Signal2<void, int, int> drag_end;    // arguments are dx and dy
 		SigC::Signal0<void>           drag_cancel;
 
+	    protected:
+		// Screen (physical) dimensions
+		virtual void get_bounds (int &x1, int &y1,
+					 int &x2, int &y2);
+
+	    public:
+		virtual bool is_within  (int x1, int y1,
+					 int x2, int y2);
+
+
 	    private:
 		void canvas_event_cb  (GdkEvent *event);
 
