@@ -1,4 +1,4 @@
-//$Id: form-canvas.cc,v 1.4 2002/03/23 23:19:25 cactus Exp $ -*- c++ -*-
+//$Id: form-canvas.cc,v 1.5 2002/05/01 21:02:31 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -24,6 +24,7 @@
 #include <gnome--/canvas-group.h>
 #include <gnome--/canvas-polygon.h>
 #include <gnome--/canvas-rect.h>
+#include <gtk--/main.h>
 #include <gdk-pixbuf/gnome-canvas-pixbuf.h>
 #include <sigc++/retbind.h>
 #include <gnome--/app-helper.h>
@@ -47,7 +48,8 @@ FormCanvasItem::FormCanvasItem (Widgets::Form      *form_widget,
     background_item (0),
     frame_group (0),
     title_group (0),
-    widget_group (0)
+    widget_group (0),
+    dirty (false)
 {
     using namespace SigC;
 
@@ -62,10 +64,29 @@ FormCanvasItem::FormCanvasItem (Widgets::Form      *form_widget,
 			 _("_Edit"), clicked.slot ()));
     Gnome::UI::fill (popup_menu, popup_menu_list, *(popup_menu.get_accel_group ()));
 
-    res->changed.connect (slot (this, &FormCanvasItem::update));
+    res->changed.connect (slot (this, &FormCanvasItem::resource_changed_cb));
     update ();
 }
 
+
+void FormCanvasItem::resource_changed_cb ()
+{
+    if (!dirty)
+    {
+	dirty = true;
+	Gtk::Main::idle.connect (SigC::retbind (
+	    SigC::slot (this, &FormCanvasItem::idle_cb), 0));
+    }
+}
+
+void FormCanvasItem::idle_cb ()
+{
+    g_return_if_fail (dirty);
+
+    update ();
+    dirty = false;
+}
+
 void FormCanvasItem::update ()
 {
     draw_background ();
