@@ -1,4 +1,4 @@
-//$Id: form.h,v 1.17 2002/02/05 15:08:56 cactus Exp $ -*- c++ -*-
+//$Id: form.h,v 1.18 2002/03/17 17:53:49 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -33,6 +33,7 @@ namespace Guikachu
 
 #include "form-res.h"
 #include "form-editor/form-element.h"
+#include "form-editor/resizeable.h"
 #include "form-editor/form-canvas.h"
 #include "form-editor/form-prop.h"
 
@@ -40,7 +41,7 @@ namespace Guikachu
 {
     namespace Widgets
     {
-	class Form: public FormElement,
+	class Form: public Resizeable,
 		    public SigC::Object
 	{		
 	    typedef std::map<Gnome::CanvasGroup *,
