@@ -1,4 +1,4 @@
-//$Id: list.cc,v 1.18 2002/02/23 20:37:11 cactus Exp $ -*- c++ -*-
+//$Id: list.cc,v 1.19 2002/03/15 17:47:08 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -27,7 +27,7 @@ using namespace Guikachu::GUI::FormEditor;
 List::List (Resources::Form   *owner,
 	    const std::string &id):
     Widget (owner, id),
-    Resizeable (changed),
+    ResizeableWidget (changed),
     AutoWidth (changed),
     editor (0),
     font (changed, 0),
