@@ -1,4 +1,4 @@
-//$Id: popup-trigger-canvas.cc,v 1.11 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
+//$Id: popup-trigger-canvas.cc,v 1.14 2002/02/10 00:01:19 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -32,7 +32,9 @@ using namespace Guikachu::GUI::FormEditor;
 
 PopupTriggerCanvasItem::PopupTriggerCanvasItem (Widgets::PopupTrigger *widget_,
 						Gnome::CanvasGroup    *parent_group):
+    CanvasItem (widget_, parent_group),
     WidgetCanvasItem (widget_, parent_group),
+    ResizeableCanvasItem (widget_, parent_group),
     widget (widget_),
     group (0)
 {
@@ -44,7 +46,7 @@ void PopupTriggerCanvasItem::update ()
     if (group)
 	delete group;
 
-    group = new Gnome::CanvasGroup (*parent_group, 0, 0);
+    group = new Gnome::CanvasGroup (*draw_group, 0, 0);
 
     GdkPixbuf *pixbuf = 0;
     if (widget->usable)
