@@ -1,6 +1,6 @@
-//$Id: table.h,v 1.7 2001/11/15 23:25:05 cactus Exp $ -*- c++ -*-
+//$Id: table.h,v 1.9 2002/01/01 21:23:41 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -49,8 +49,8 @@ namespace Guikachu
 	    
 	    virtual Type get_type () const { return WIDGET_TABLE; };
 	    
-	    virtual GUI::FormEditor::CanvasItem *create_canvas_item (GUI::FormEditor::Form *form);
-	    virtual Gtk::Widget                 *create_editor ();
+	    virtual Gtk::Widget                       *create_editor ();
+	    virtual GUI::FormEditor::WidgetCanvasItem *create_canvas_item (Gnome::CanvasGroup *parent_group);
 
 	    Property<int>               num_rows;
 	    Property<int>               num_columns;
