@@ -1,4 +1,4 @@
-//$Id: text-field-canvas.h,v 1.5 2002/01/01 21:23:41 cactus Exp $ -*- c++ -*-
+//$Id: text-field-canvas.h,v 1.6 2002/02/10 00:01:19 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,6 +21,7 @@
 
 #include "form-editor/text-field.h"
 #include "form-editor/widget-canvas.h"
+#include "form-editor/resizeable-canvas.h"
 
 namespace Guikachu
 {
@@ -28,7 +29,8 @@ namespace Guikachu
     {
 	namespace FormEditor
 	{
-	    class TextFieldCanvasItem: public WidgetCanvasItem
+	    class TextFieldCanvasItem: public WidgetCanvasItem,
+				       public ResizeableCanvasItem
 	    {
 		Widgets::TextField *widget;
 		Gnome::CanvasGroup *group;
