@@ -1,4 +1,4 @@
-//$Id: resource-manager-io.cc,v 1.27 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager-io.cc,v 1.29 2002/05/05 18:49:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -30,8 +30,9 @@
 #include <fcntl.h>
 #include <unistd.h>
 
-#include "target.h"
+#include "mainwin.h"
 
+#include "target.h"
 #include "storage.h"
 
 using namespace Guikachu;
@@ -74,62 +75,75 @@ ResourceManager::IOResult ResourceManager::load (const std::string &filename)
     
     if (!storage.load (filename))
 	return IO_INVALID;
-	
+
+    // Reset flags
+    encoding_fixed = false;
+    
     StorageNode root_node = storage.get_root ();
     if (root_node.name () != "guikachu")
         return IO_INVALID;
 
-    /*
-     * Walk the tree
-     */
     reset ();
 
+    // Walk the tree
     for (StorageNode curr_node = root_node.children ();
          curr_node; curr_node++)
     {
 	if (curr_node.name () == "application")
 	    app->load (curr_node);
+	
 	else if (curr_node.name () == "target")
 	    target->load (curr_node);
+	
 	else
 	    load_resource (curr_node);
     }
 
     clear_dirty ();
 
+    if (encoding_fixed)
+    {
+	encoding_warning ();
+	set_dirty ();
+    }
+    
     return IO_OK;
 }
 
 Resource* ResourceManager::load_resource (StorageNode &node)
 {
-    Resource *resource = 0;
+    Resources::Type res_type;
 
     std::string node_name = node.name ();
+    
+    if (node_name == "dialog")
+	res_type = Resources::RESOURCE_DIALOG;
+    else if (node_name == "form")
+	res_type = Resources::RESOURCE_FORM;
+    else if (node_name == "menu")
+	res_type = Resources::RESOURCE_MENU;
+    else if (node_name == "string")
+	res_type = Resources::RESOURCE_STRING;
+    else if (node_name == "stringlist")
+	res_type = Resources::RESOURCE_STRINGLIST;
+    else if (node_name == "blob")
+	res_type = Resources::RESOURCE_BLOB;
+    else
+    {
+	g_warning ("Unknown resource type `%s'", node_name.c_str ());
+	return 0;
+    }
+
     std::string id = node.get_prop<std::string> ("id");
 
     if (id == "")
     {
 	g_warning ("`%s': Missing ID field", node_name.c_str ());
-	return NULL;
+	return 0;
     }
-
-    if (node_name == "dialog")
-	resource = create_resource (Resources::RESOURCE_DIALOG, id);
-    else if (node_name == "form")
-	resource = create_resource (Resources::RESOURCE_FORM, id);
-    else if (node_name == "menu")
-	resource = create_resource (Resources::RESOURCE_MENU, id);
-    else if (node_name == "string")
-	resource = create_resource (Resources::RESOURCE_STRING, id);
-    else if (node_name == "stringlist")
-	resource = create_resource (Resources::RESOURCE_STRINGLIST, id);
-    else if (node_name == "blob")
-	resource = create_resource (Resources::RESOURCE_BLOB, id);
-    else
-	g_warning ("Unknown resource type `%s'", node_name.c_str ());
-
-    if (resource)
-	resource->load (node);
+    
+    Resource *resource = create_resource (res_type, id);
+    resource->load (node);
     
     return resource;
 }
@@ -180,15 +194,44 @@ void ResourceManager::export_rcp (const std::string &filename)
 	 << ". Do not edit it manually." << std::endl;
     fout << " * Creation date: " << date_str; // ctime ()'s return value ends in \n
     fout << " */" << std::endl << std::endl;;
-    
-    fout << app;
-    
+
+    // Export blobs before anything else, to allow #includes and whatnot
     for (std::map<std::string, Resource*>::iterator i = resource_map.begin ();
-	 i != resource_map.end ();
-	 i++)
+	 i != resource_map.end (); i++)
     {
-	fout << i->second;
+	if (i->second->get_type () == Resources::RESOURCE_BLOB)
+	    fout << i->second;
+    }
+
+    // Export per-app data
+    fout << app;
+
+    // Export the rest of the resources
+    for (std::map<std::string, Resource*>::iterator i = resource_map.begin ();
+	 i != resource_map.end (); i++)
+    {
+	if (i->second->get_type () != Resources::RESOURCE_BLOB)
+	    fout << i->second;
     }
     
     fout.close ();
 }
+
+void ResourceManager::encoding_fixed_cb ()
+{
+    encoding_fixed = true;
+}
+
+void ResourceManager::encoding_warning ()
+{
+    GUI::show_warning (_("Previous releases of Guikachu always stored\n"
+			 "strings in the local encoding, while PalmOS\n"
+			 "uses the Latin-1 character  set. The encoding\n"
+			 "of old Guikachu files can not be determined,\n"
+			 "so all non-ASCII characters have been\n"
+			 "automatically converted to escape sequences.\n"
+			 "\n"
+			 "Please review the results of the automatic\n"
+			 "conversion after the file had been loaded."));
+}
+
