@@ -1,4 +1,4 @@
-//$Id: session.cc,v 1.6 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: session.cc,v 1.7 2002/05/05 15:28:33 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -110,5 +110,9 @@ void Guikachu::Main::save_open_file ()
 
 void Guikachu::Main::set_filename (const std::string &filename)
 {
+    char *dirname = g_dirname (filename.c_str ());
+    chdir (dirname);
+    g_free (dirname);
+    
     last_filename = filename;
 }
